==================================
Interactions (:mod:`interactions`)
==================================

.. automodule:: orangecanvas.document.interactions


.. autoclass:: UserInteraction
   :members:
   :exclude-members:
      started,
      finished,
      ended,
      canceled
   :member-order: bysource
   :show-inheritance:

   .. automethod:: started()

   .. automethod:: finished()

   .. automethod:: ended()

   .. automethod:: canceled()


.. autoclass:: DropAction
   :members:
   :member-order: bysource
   :show-inheritance:


.. autoclass:: DropHandler
   :members:
   :member-order: bysource
   :show-inheritance:


.. autoclass:: DropHandlerAction
   :members:
   :member-order: bysource
   :show-inheritance:

.. autoclass:: NodeFromMimeDataDropHandler
   :members:
   :member-order: bysource
   :show-inheritance:

.. autoclass:: PluginDropHandler
   :members:
   :member-order: bysource
   :show-inheritance:
